==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/dlnaexport/kipiplugin_dlnaexport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=DLNAExport
Name[ca]=DLNAExport
Name[cs]=DLNAExport
Name[da]=DLNAExport
Name[de]=DLNAE-Export
Name[el]=DLNAExport
Name[et]=DLNA eksport
Name[ga]=DLNAExport
Name[hu]=DLNA exportálás
Name[is]=DLNA-útflutningur
Name[it]=Esportazione a DLNA
Name[nb]=DLNAEksport
Name[nl]=DLNA-export
Name[pl]=EksportDoDLNA
Name[pt]=DLNAExport
Name[pt_BR]=Exportar para DLNA
Name[sl]=DLNAExport
Name[sv]=Export till DLNA
Name[uk]=Експорт до DLNA
Name[x-test]=xxDLNAExportxx
Name[zh_TW]=DLNA匯出
Comment=A tool to export collection on DLNA network service
Comment[ca]=Una eina per exportar col·leccions sobre el servei de xarxa DLNA
Comment[cs]=Nástroj pro export kolekce do síťové služby DLNA
Comment[da]=Et værktøj til at eksportere samling på DLNA-netværkstjenesten
Comment[de]=Ein Werkzeug, um Bilder zu einem DLNA-Netzwerkdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής συλλογής σε δικτυακή υπηρεσία DLNA
Comment[et]=Tööriist kogu eksportimiseks DLNA võrguteenusesse
Comment[ga]=Uirlis a easpórtálann bailiúchán ar seirbhís líonra DLNA
Comment[hu]=Egy eszköz gyűjtemények exportálásához DLNA hálózati szolgáltatásba
Comment[is]=Tól til að flytja myndasöfn yfir í DLNA netþjónustu
Comment[it]=Uno strumento per esportare raccolte sul servizio in rete DLNA
Comment[nb]=Et verktøy for å eksportere samling på en DLNA nettverkstjeneste
Comment[nl]=Een hulpmiddel om een verzameling naar een DLNA-netwerk te exporteren
Comment[pl]=Narzędzie do eksportowania zbioru do usługi sieciowej DLNA
Comment[pt]=Uma ferramenta para exportar a colecção num serviço de rede DLNA
Comment[pt_BR]=Uma ferramenta para exportar a coleção para um serviço de rede DLNA
Comment[sl]=Orodje za izvoz zbirk na omrežno storitev DLNA
Comment[sv]=Ett verktyg för att exportera bilder till en DLNA nätverkstjänst
Comment[uk]=Інструмент для експорту збірок до служби DLNA у мережі
Comment[x-test]=xxA tool to export collection on DLNA network servicexx
Comment[zh_TW]=匯出 DLNA 網路服務上的收藏的工具
Type=Service
Icon=dlna
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dlnaexport
author=Smit Mehta, smit dot meh at gmail dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=

==> digikam_3.5.0.orig.tar.bz2: digikam-3.5.0/extra/kipi-plugins/dlnaexport/kipiplugin_dlnaexport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=DLNAExport
Name=DLNAExport
Name[ca]=Exportador via DLNA
Name[ca@valencia]=DLNAExport
Name[cs]=DLNAExport
Name[da]=DLNAExport
Name[de]=DLNAE-Export
Name[el]=DLNAExport
Name[es]=Exportar a DLNA
Name[et]=DLNA eksport
Name[fr]=Exportation « DLNA »
Name[ga]=DLNAExport
Name[gl]=DLNAExport
Name[hu]=DLNA exportálás
Name[is]=DLNA-útflutningur
Name[it]=Esportazione a DLNA
Name[nb]=DLNAEksport
Name[nl]=DLNA-export
Name[pl]=EksportDoDLNA
Name[pt]=DLNAExport
Name[pt_BR]=Exportar para DLNA
Name[sl]=DLNAExport
Name[sv]=Export till DLNA
Name[uk]=Експорт до DLNA
Name[x-test]=xxDLNAExportxx
Name[zh_TW]=DLNA匯出
Comment=A tool to export collection on DLNA network service
Comment[ca]=Una eina per exportar col·leccions sobre el servei de xarxa DLNA
Comment[ca@valencia]=Una eina per exportar col·leccions sobre el servei de xarxa DLNA
Comment[cs]=Nástroj pro export sbírky do síťové služby DLNA
Comment[da]=Et værktøj til at eksportere samling på DLNA-netværkstjenesten
Comment[de]=Ein Werkzeug, um Bilder zu einem DLNA-Netzwerkdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής συλλογής σε δικτυακή υπηρεσία DLNA
Comment[es]=Una herramienta para exportar la colección a un servicio de red DLNA
Comment[et]=Tööriist kogu eksportimiseks DLNA võrguteenusesse
Comment[fr]=Outil pour l'exportation d'une collection sur réseau « DLNA »
Comment[ga]=Uirlis a easpórtálann bailiúchán ar seirbhís líonra DLNA
Comment[gl]=Ferramenta para exportar coleccións nun servizo de rede DLNA.
Comment[hu]=Egy eszköz gyűjtemények exportálásához DLNA hálózati szolgáltatásba
Comment[is]=Tól til að flytja myndasöfn yfir í DLNA netþjónustu
Comment[it]=Uno strumento per esportare raccolte sul servizio in rete DLNA
Comment[nb]=Et verktøy for å eksportere samling på en DLNA nettverkstjeneste
Comment[nl]=Een hulpmiddel om een verzameling naar een DLNA-netwerk te exporteren
Comment[pl]=Narzędzie do eksportowania zbioru do usługi sieciowej DLNA
Comment[pt]=Uma ferramenta para exportar a colecção num serviço de rede DLNA
Comment[pt_BR]=Uma ferramenta para exportar a coleção para um serviço de rede DLNA
Comment[sl]=Orodje za izvoz zbirk na omrežno storitev DLNA
Comment[sv]=Ett verktyg för att exportera bilder till en DLNA nätverkstjänst
Comment[uk]=Інструмент для експорту збірок до служби DLNA у мережі
Comment[x-test]=xxA tool to export collection on DLNA network servicexx
Comment[zh_TW]=匯出 DLNA 網路服務上的收藏的工具
Type=Service
Icon=kipi-dlna
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dlnaexport
author=Smit Mehta, smit dot meh at gmail dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=
